You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by tn...@apache.org on 2012/08/06 22:34:43 UTC

svn commit: r1369988 - in /commons/proper/collections/trunk/src/test/java/org/apache/commons/collections: ./ bag/ buffer/ collection/ list/ map/ set/

Author: tn
Date: Mon Aug  6 20:34:42 2012
New Revision: 1369988

URL: http://svn.apache.org/viewvc?rev=1369988&view=rev
Log:
Renamed collection tests.

Added:
    commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/AbstractCollectionTest.java
      - copied, changed from r1366804, commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/AbstractTestCollection.java
    commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/CompositeCollectionTest.java
      - copied, changed from r1361641, commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/TestCompositeCollection.java
    commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/PredicatedCollectionTest.java
      - copied, changed from r1361641, commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/TestPredicatedCollection.java
    commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/SynchronizedCollectionTest.java
      - copied, changed from r1361641, commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/TestSynchronizedCollection.java
    commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/TransformedCollectionTest.java
      - copied, changed from r1361641, commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/TestTransformedCollection.java
    commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/UnmodifiableBoundedCollectionTest.java
      - copied, changed from r1361641, commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/TestUnmodifiableBoundedCollection.java
    commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/UnmodifiableCollectionTest.java
      - copied, changed from r1361641, commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/TestUnmodifiableCollection.java
Removed:
    commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/AbstractTestCollection.java
    commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/TestCompositeCollection.java
    commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/TestPredicatedCollection.java
    commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/TestSynchronizedCollection.java
    commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/TestTransformedCollection.java
    commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/TestUnmodifiableBoundedCollection.java
    commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/TestUnmodifiableCollection.java
Modified:
    commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/TestMapUtils.java
    commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/bag/TransformedBagTest.java
    commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/bag/TransformedSortedBagTest.java
    commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/buffer/TestBoundedFifoBuffer.java
    commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/buffer/TestCircularFifoBuffer.java
    commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/buffer/TestPredicatedBuffer.java
    commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/buffer/TestPriorityBuffer.java
    commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/buffer/TestSynchronizedBuffer.java
    commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/buffer/TestTransformedBuffer.java
    commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/buffer/TestUnboundedFifoBuffer.java
    commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/buffer/TestUnmodifiableBuffer.java
    commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/list/AbstractTestList.java
    commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/list/TestTransformedList.java
    commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/map/AbstractTestMap.java
    commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/map/TestTransformedMap.java
    commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/map/TestTransformedSortedMap.java
    commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/set/AbstractTestSet.java
    commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/set/TestTransformedSet.java
    commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/set/TestTransformedSortedSet.java

Modified: commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/TestMapUtils.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/TestMapUtils.java?rev=1369988&r1=1369987&r2=1369988&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/TestMapUtils.java (original)
+++ commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/TestMapUtils.java Mon Aug  6 20:34:42 2012
@@ -36,7 +36,7 @@ import org.apache.commons.collections.ke
 import org.apache.commons.collections.map.HashedMap;
 import org.apache.commons.collections.map.LazyMap;
 import org.apache.commons.collections.map.PredicatedMap;
-import org.apache.commons.collections.collection.TestTransformedCollection;
+import org.apache.commons.collections.collection.TransformedCollectionTest;
 
 /**
  * Tests for MapUtils.
@@ -756,7 +756,7 @@ public class TestMapUtils extends BulkTe
 
         // Now test key transform population
         Map<Object, Object> map = new HashMap<Object, Object>();
-        MapUtils.populateMap(map, list, TestTransformedCollection.STRING_TO_INTEGER_TRANSFORMER);
+        MapUtils.populateMap(map, list, TransformedCollectionTest.STRING_TO_INTEGER_TRANSFORMER);
         assertEquals(list.size(), map.size());
 
         for (int i = 0; i < list.size(); i++) {
@@ -768,7 +768,7 @@ public class TestMapUtils extends BulkTe
 
         // Now test both Key-Value transform population
         map = new HashMap<Object, Object>();
-        MapUtils.populateMap(map, list, TestTransformedCollection.STRING_TO_INTEGER_TRANSFORMER, TestTransformedCollection.STRING_TO_INTEGER_TRANSFORMER);
+        MapUtils.populateMap(map, list, TransformedCollectionTest.STRING_TO_INTEGER_TRANSFORMER, TransformedCollectionTest.STRING_TO_INTEGER_TRANSFORMER);
 
         assertEquals(list.size(), map.size());
         for (int i = 0; i < list.size(); i++) {

Modified: commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/bag/TransformedBagTest.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/bag/TransformedBagTest.java?rev=1369988&r1=1369987&r2=1369988&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/bag/TransformedBagTest.java (original)
+++ commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/bag/TransformedBagTest.java Mon Aug  6 20:34:42 2012
@@ -18,7 +18,7 @@ package org.apache.commons.collections.b
 
 import org.apache.commons.collections.Bag;
 import org.apache.commons.collections.Transformer;
-import org.apache.commons.collections.collection.TestTransformedCollection;
+import org.apache.commons.collections.collection.TransformedCollectionTest;
 
 /**
  * Extension of {@link AbstractBagTest} for exercising the {@link TransformedBag}
@@ -37,14 +37,14 @@ public class TransformedBagTest<T> exten
     @SuppressWarnings("unchecked")
     public Bag<T> makeObject() {
         return TransformedBag.transformingBag(new HashBag<T>(),
-                (Transformer<T, T>) TestTransformedCollection.NOOP_TRANSFORMER);
+                (Transformer<T, T>) TransformedCollectionTest.NOOP_TRANSFORMER);
     }
 
     @SuppressWarnings("unchecked")
     public void testTransformedBag() {
         //T had better be Object!
         Bag<T> bag = TransformedBag.transformingBag(new HashBag<T>(),
-                (Transformer<T, T>) TestTransformedCollection.STRING_TO_INTEGER_TRANSFORMER);
+                (Transformer<T, T>) TransformedCollectionTest.STRING_TO_INTEGER_TRANSFORMER);
         assertEquals(0, bag.size());
         Object[] els = new Object[] {"1", "3", "5", "7", "2", "4", "6"};
         for (int i = 0; i < els.length; i++) {
@@ -66,7 +66,7 @@ public class TransformedBagTest<T> exten
             originalBag.add((T) els[i]);
         }
         Bag<T> bag = TransformedBag.transformedBag(originalBag,
-                (Transformer<T, T>) TestTransformedCollection.STRING_TO_INTEGER_TRANSFORMER);
+                (Transformer<T, T>) TransformedCollectionTest.STRING_TO_INTEGER_TRANSFORMER);
         assertEquals(els.length, bag.size());
         for (int i = 0; i < els.length; i++) {
             assertEquals(true, bag.contains(new Integer((String) els[i])));

Modified: commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/bag/TransformedSortedBagTest.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/bag/TransformedSortedBagTest.java?rev=1369988&r1=1369987&r2=1369988&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/bag/TransformedSortedBagTest.java (original)
+++ commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/bag/TransformedSortedBagTest.java Mon Aug  6 20:34:42 2012
@@ -19,7 +19,7 @@ package org.apache.commons.collections.b
 import org.apache.commons.collections.Bag;
 import org.apache.commons.collections.SortedBag;
 import org.apache.commons.collections.Transformer;
-import org.apache.commons.collections.collection.TestTransformedCollection;
+import org.apache.commons.collections.collection.TransformedCollectionTest;
 
 /**
  * Extension of {@link AbstractSortedBagTest} for exercising the {@link TransformedSortedBag}
@@ -37,12 +37,12 @@ public class TransformedSortedBagTest<T>
     @Override
     @SuppressWarnings("unchecked")
     public SortedBag<T> makeObject() {
-        return TransformedSortedBag.transformingSortedBag(new TreeBag<T>(), (Transformer<T, T>) TestTransformedCollection.NOOP_TRANSFORMER);
+        return TransformedSortedBag.transformingSortedBag(new TreeBag<T>(), (Transformer<T, T>) TransformedCollectionTest.NOOP_TRANSFORMER);
     }
 
     @SuppressWarnings("unchecked")
     public void testTransformedBag() {
-        SortedBag<T> bag = TransformedSortedBag.transformingSortedBag(new TreeBag<T>(), (Transformer<T, T>) TestTransformedCollection.STRING_TO_INTEGER_TRANSFORMER);
+        SortedBag<T> bag = TransformedSortedBag.transformingSortedBag(new TreeBag<T>(), (Transformer<T, T>) TransformedCollectionTest.STRING_TO_INTEGER_TRANSFORMER);
         assertEquals(0, bag.size());
         Object[] els = new Object[] {"1", "3", "5", "7", "2", "4", "6"};
         for (int i = 0; i < els.length; i++) {
@@ -61,7 +61,7 @@ public class TransformedSortedBagTest<T>
         for (int i = 0; i < els.length; i++) {
             originalBag.add(els[i]);
         }
-        Bag<?> bag = TransformedBag.transformedBag(originalBag, TestTransformedCollection.STRING_TO_INTEGER_TRANSFORMER);
+        Bag<?> bag = TransformedBag.transformedBag(originalBag, TransformedCollectionTest.STRING_TO_INTEGER_TRANSFORMER);
         assertEquals(els.length, bag.size());
         for (int i = 0; i < els.length; i++) {
             assertEquals(true, bag.contains(new Integer((String) els[i])));

Modified: commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/buffer/TestBoundedFifoBuffer.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/buffer/TestBoundedFifoBuffer.java?rev=1369988&r1=1369987&r2=1369988&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/buffer/TestBoundedFifoBuffer.java (original)
+++ commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/buffer/TestBoundedFifoBuffer.java Mon Aug  6 20:34:42 2012
@@ -25,7 +25,7 @@ import junit.framework.Test;
 
 import org.apache.commons.collections.BufferUnderflowException;
 import org.apache.commons.collections.BulkTest;
-import org.apache.commons.collections.collection.AbstractTestCollection;
+import org.apache.commons.collections.collection.AbstractCollectionTest;
 
 /**
  * Test cases for BoundedFifoBuffer.
@@ -34,7 +34,7 @@ import org.apache.commons.collections.co
  *
  * @author Paul Jack
  */
-public class TestBoundedFifoBuffer<E> extends AbstractTestCollection<E> {
+public class TestBoundedFifoBuffer<E> extends AbstractCollectionTest<E> {
 
     public TestBoundedFifoBuffer(String n) {
         super(n);

Modified: commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/buffer/TestCircularFifoBuffer.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/buffer/TestCircularFifoBuffer.java?rev=1369988&r1=1369987&r2=1369988&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/buffer/TestCircularFifoBuffer.java (original)
+++ commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/buffer/TestCircularFifoBuffer.java Mon Aug  6 20:34:42 2012
@@ -29,7 +29,7 @@ import junit.framework.Test;
 import org.apache.commons.collections.Buffer;
 import org.apache.commons.collections.BufferUnderflowException;
 import org.apache.commons.collections.BulkTest;
-import org.apache.commons.collections.collection.AbstractTestCollection;
+import org.apache.commons.collections.collection.AbstractCollectionTest;
 
 /**
  * Test cases for CircularFifoBuffer.
@@ -38,7 +38,7 @@ import org.apache.commons.collections.co
  *
  * @author Stephen Colebourne
  */
-public class TestCircularFifoBuffer<E> extends AbstractTestCollection<E> {
+public class TestCircularFifoBuffer<E> extends AbstractCollectionTest<E> {
 
     public TestCircularFifoBuffer(String n) {
         super(n);

Modified: commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/buffer/TestPredicatedBuffer.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/buffer/TestPredicatedBuffer.java?rev=1369988&r1=1369987&r2=1369988&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/buffer/TestPriorityBuffer.java (original)
+++ commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/buffer/TestPriorityBuffer.java Mon Aug  6 20:34:42 2012
@@ -27,7 +27,7 @@ import java.util.Random;
 import org.apache.commons.collections.Buffer;
 import org.apache.commons.collections.BufferUnderflowException;
 import org.apache.commons.collections.ComparatorUtils;
-import org.apache.commons.collections.collection.AbstractTestCollection;
+import org.apache.commons.collections.collection.AbstractCollectionTest;
 import org.apache.commons.collections.comparators.ComparableComparator;
 import org.apache.commons.collections.comparators.ReverseComparator;
 
@@ -40,7 +40,7 @@ import org.apache.commons.collections.co
  * @author Steve Phelps
  */
 @SuppressWarnings("boxing")
-public class TestPriorityBuffer<E> extends AbstractTestCollection<E> {
+public class TestPriorityBuffer<E> extends AbstractCollectionTest<E> {
 
     public TestPriorityBuffer(String testName) {
         super(testName);

Modified: commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/buffer/TestSynchronizedBuffer.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/buffer/TestSynchronizedBuffer.java?rev=1369988&r1=1369987&r2=1369988&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/buffer/TestTransformedBuffer.java (original)
+++ commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/buffer/TestTransformedBuffer.java Mon Aug  6 20:34:42 2012
@@ -19,7 +19,7 @@ package org.apache.commons.collections.b
 import junit.framework.TestCase;
 import org.apache.commons.collections.ArrayStack;
 import org.apache.commons.collections.Buffer;
-import org.apache.commons.collections.collection.TestTransformedCollection;
+import org.apache.commons.collections.collection.TransformedCollectionTest;
 
 /**
  * Extension of {@link TestCase} for exercising the {@link TransformedBuffer}
@@ -37,7 +37,7 @@ public class TestTransformedBuffer exten
     }
 
     public void testTransformedBuffer() {
-        Buffer<Object> buffer = TransformedBuffer.transformingBuffer(new ArrayStack<Object>(), TestTransformedCollection.STRING_TO_INTEGER_TRANSFORMER);
+        Buffer<Object> buffer = TransformedBuffer.transformingBuffer(new ArrayStack<Object>(), TransformedCollectionTest.STRING_TO_INTEGER_TRANSFORMER);
         assertEquals(0, buffer.size());
         Object[] els = new Object[] { "1", "3", "5", "7", "2", "4", "6" };
         for (int i = 0; i < els.length; i++) {
@@ -58,7 +58,7 @@ public class TestTransformedBuffer exten
         for (int i = 0; i < els.length; i++) {
             originalBuffer.add(els[i]);
         }
-        Buffer buffer = TransformedBuffer.transformedBuffer(originalBuffer, TestTransformedCollection.STRING_TO_INTEGER_TRANSFORMER);
+        Buffer buffer = TransformedBuffer.transformedBuffer(originalBuffer, TransformedCollectionTest.STRING_TO_INTEGER_TRANSFORMER);
         assertEquals(els.length, buffer.size());
         for (int i = 0; i < els.length; i++) {
             assertEquals(true, buffer.contains(new Integer((String) els[i])));

Modified: commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/buffer/TestUnboundedFifoBuffer.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/buffer/TestUnboundedFifoBuffer.java?rev=1369988&r1=1369987&r2=1369988&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/buffer/TestUnboundedFifoBuffer.java (original)
+++ commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/buffer/TestUnboundedFifoBuffer.java Mon Aug  6 20:34:42 2012
@@ -24,7 +24,7 @@ import java.util.List;
 import junit.framework.Test;
 
 import org.apache.commons.collections.BulkTest;
-import org.apache.commons.collections.collection.AbstractTestCollection;
+import org.apache.commons.collections.collection.AbstractCollectionTest;
 
 /**
  * Test cases for UnboundedFifoBuffer.
@@ -33,7 +33,7 @@ import org.apache.commons.collections.co
  *
  * @author Unknown
  */
-public class TestUnboundedFifoBuffer<E> extends AbstractTestCollection<E> {
+public class TestUnboundedFifoBuffer<E> extends AbstractCollectionTest<E> {
 
     public TestUnboundedFifoBuffer(String n) {
         super(n);

Modified: commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/buffer/TestUnmodifiableBuffer.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/buffer/TestUnmodifiableBuffer.java?rev=1369988&r1=1369987&r2=1369988&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/buffer/TestUnmodifiableBuffer.java (original)
+++ commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/buffer/TestUnmodifiableBuffer.java Mon Aug  6 20:34:42 2012
@@ -21,10 +21,10 @@ import java.util.Collection;
 
 import org.apache.commons.collections.ArrayStack;
 import org.apache.commons.collections.Buffer;
-import org.apache.commons.collections.collection.AbstractTestCollection;
+import org.apache.commons.collections.collection.AbstractCollectionTest;
 
 /**
- * Extension of {@link AbstractTestCollection} for exercising the
+ * Extension of {@link AbstractCollectionTest} for exercising the
  * {@link UnmodifiableBuffer} implementation.
  *
  * @since Commons Collections 3.1
@@ -33,7 +33,7 @@ import org.apache.commons.collections.co
  * @author Phil Steitz
  * @author Stephen Colebourne
  */
-public class TestUnmodifiableBuffer<E> extends AbstractTestCollection<E> {
+public class TestUnmodifiableBuffer<E> extends AbstractCollectionTest<E> {
 
     public TestUnmodifiableBuffer(String testName) {
         super(testName);

Copied: commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/AbstractCollectionTest.java (from r1366804, commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/AbstractTestCollection.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/AbstractCollectionTest.java?p2=commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/AbstractCollectionTest.java&p1=commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/AbstractTestCollection.java&r1=1366804&r2=1369988&rev=1369988&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/AbstractTestCollection.java (original)
+++ commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/AbstractCollectionTest.java Mon Aug  6 20:34:42 2012
@@ -125,7 +125,7 @@ import org.apache.commons.collections.Ab
  * @author Neil O'Toole
  * @author Stephen Colebourne
  */
-public abstract class AbstractTestCollection<E> extends AbstractTestObject {
+public abstract class AbstractCollectionTest<E> extends AbstractTestObject {
 
     //
     // NOTE:
@@ -160,7 +160,7 @@ public abstract class AbstractTestCollec
      *
      * @param testName  the test class name
      */
-    public AbstractTestCollection(String testName) {
+    public AbstractCollectionTest(String testName) {
         super(testName);
     }
 

Copied: commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/CompositeCollectionTest.java (from r1361641, commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/TestCompositeCollection.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/CompositeCollectionTest.java?p2=commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/CompositeCollectionTest.java&p1=commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/TestCompositeCollection.java&r1=1361641&r2=1369988&rev=1369988&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/TestCompositeCollection.java (original)
+++ commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/CompositeCollectionTest.java Mon Aug  6 20:34:42 2012
@@ -24,7 +24,7 @@ import java.util.Iterator;
 import java.util.List;
 
 /**
- * Extension of {@link AbstractTestCollection} for exercising the
+ * Extension of {@link AbstractCollectionTest} for exercising the
  * {@link CompositeCollection} implementation.
  *
  * @since Commons Collections 3.0
@@ -33,9 +33,9 @@ import java.util.List;
  * @author Brian McCallister
  * @author Phil Steitz
  */
-public class TestCompositeCollection<E> extends AbstractTestCollection<E> {
+public class CompositeCollectionTest<E> extends AbstractCollectionTest<E> {
 
-    public TestCompositeCollection(String name) {
+    public CompositeCollectionTest(String name) {
         super(name);
     }
 

Copied: commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/PredicatedCollectionTest.java (from r1361641, commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/TestPredicatedCollection.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/PredicatedCollectionTest.java?p2=commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/PredicatedCollectionTest.java&p1=commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/TestPredicatedCollection.java&r1=1361641&r2=1369988&rev=1369988&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/TestPredicatedCollection.java (original)
+++ commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/PredicatedCollectionTest.java Mon Aug  6 20:34:42 2012
@@ -25,7 +25,7 @@ import org.apache.commons.collections.Pr
 import org.apache.commons.collections.functors.TruePredicate;
 
 /**
- * Extension of {@link AbstractTestCollection} for exercising the 
+ * Extension of {@link AbstractCollectionTest} for exercising the 
  * {@link PredicatedCollection} implementation.
  *
  * @since Commons Collections 3.0
@@ -33,9 +33,9 @@ import org.apache.commons.collections.fu
  *
  * @author Phil Steitz
  */
-public class TestPredicatedCollection<E> extends AbstractTestCollection<E> {
+public class PredicatedCollectionTest<E> extends AbstractCollectionTest<E> {
 
-    public TestPredicatedCollection(String name) {
+    public PredicatedCollectionTest(String name) {
         super(name);
     }
 

Copied: commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/SynchronizedCollectionTest.java (from r1361641, commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/TestSynchronizedCollection.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/SynchronizedCollectionTest.java?p2=commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/SynchronizedCollectionTest.java&p1=commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/TestSynchronizedCollection.java&r1=1361641&r2=1369988&rev=1369988&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/TestSynchronizedCollection.java (original)
+++ commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/SynchronizedCollectionTest.java Mon Aug  6 20:34:42 2012
@@ -21,7 +21,7 @@ import java.util.Arrays;
 import java.util.Collection;
 
 /**
- * Extension of {@link AbstractTestCollection} for exercising the
+ * Extension of {@link AbstractCollectionTest} for exercising the
  * {@link SynchronizedCollection} implementation.
  *
  * @since Commons Collections 3.1
@@ -30,9 +30,9 @@ import java.util.Collection;
  * @author Phil Steitz
  * @author Stephen Colebourne
  */
-public class TestSynchronizedCollection<E> extends AbstractTestCollection<E> {
+public class SynchronizedCollectionTest<E> extends AbstractCollectionTest<E> {
 
-    public TestSynchronizedCollection(String testName) {
+    public SynchronizedCollectionTest(String testName) {
         super(testName);
     }
 

Copied: commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/TransformedCollectionTest.java (from r1361641, commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/TestTransformedCollection.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/TransformedCollectionTest.java?p2=commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/TransformedCollectionTest.java&p1=commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/TestTransformedCollection.java&r1=1361641&r2=1369988&rev=1369988&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/TestTransformedCollection.java (original)
+++ commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/TransformedCollectionTest.java Mon Aug  6 20:34:42 2012
@@ -25,7 +25,7 @@ import org.apache.commons.collections.Tr
 import org.apache.commons.collections.TransformerUtils;
 
 /**
- * Extension of {@link AbstractTestCollection} for exercising the {@link TransformedCollection}
+ * Extension of {@link AbstractCollectionTest} for exercising the {@link TransformedCollection}
  * implementation.
  *
  * @since Commons Collections 3.0
@@ -33,7 +33,7 @@ import org.apache.commons.collections.Tr
  *
  * @author Stephen Colebourne
  */
-public class TestTransformedCollection extends AbstractTestCollection<Object> {
+public class TransformedCollectionTest extends AbstractCollectionTest<Object> {
     
     private static class StringToInteger implements Transformer<Object, Object> {
         public Object transform(Object input) {
@@ -44,7 +44,7 @@ public class TestTransformedCollection e
     public static final Transformer<Object, Object> NOOP_TRANSFORMER = TransformerUtils.nopTransformer();
     public static final Transformer<Object, Object> STRING_TO_INTEGER_TRANSFORMER = new StringToInteger();
 
-    public TestTransformedCollection(String testName) {
+    public TransformedCollectionTest(String testName) {
         super(testName);
     }
 
@@ -105,7 +105,7 @@ public class TestTransformedCollection e
         for (int i = 0; i < els.length; i++) {
             originalCollection.add(els[i]);
         }
-        Collection collection = TransformedCollection.transformedCollection(originalCollection, TestTransformedCollection.STRING_TO_INTEGER_TRANSFORMER);
+        Collection<Object> collection = TransformedCollection.transformedCollection(originalCollection, TransformedCollectionTest.STRING_TO_INTEGER_TRANSFORMER);
         assertEquals(els.length, collection.size());
         for (int i = 0; i < els.length; i++) {
             assertEquals(true, collection.contains(new Integer((String) els[i])));

Copied: commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/UnmodifiableBoundedCollectionTest.java (from r1361641, commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/TestUnmodifiableBoundedCollection.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/UnmodifiableBoundedCollectionTest.java?p2=commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/UnmodifiableBoundedCollectionTest.java&p1=commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/TestUnmodifiableBoundedCollection.java&r1=1361641&r2=1369988&rev=1369988&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/TestUnmodifiableBoundedCollection.java (original)
+++ commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/UnmodifiableBoundedCollectionTest.java Mon Aug  6 20:34:42 2012
@@ -26,12 +26,12 @@ import org.apache.commons.collections.Bu
 import org.apache.commons.collections.buffer.BoundedBuffer;
 
 /**
- * Extension of {@link AbstractTestCollection} for exercising the
+ * Extension of {@link AbstractCollectionTest} for exercising the
  * {@link UnmodifiableBoundedCollection} implementation.
  */
-public class TestUnmodifiableBoundedCollection<E> extends AbstractTestCollection<E> {
+public class UnmodifiableBoundedCollectionTest<E> extends AbstractCollectionTest<E> {
 
-    public TestUnmodifiableBoundedCollection(String testName) {
+    public UnmodifiableBoundedCollectionTest(String testName) {
         super(testName);
     }
 

Copied: commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/UnmodifiableCollectionTest.java (from r1361641, commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/TestUnmodifiableCollection.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/UnmodifiableCollectionTest.java?p2=commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/UnmodifiableCollectionTest.java&p1=commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/TestUnmodifiableCollection.java&r1=1361641&r2=1369988&rev=1369988&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/list/AbstractTestList.java (original)
+++ commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/list/AbstractTestList.java Mon Aug  6 20:34:42 2012
@@ -32,7 +32,7 @@ import java.util.ListIterator;
 import java.util.NoSuchElementException;
 
 import org.apache.commons.collections.BulkTest;
-import org.apache.commons.collections.collection.AbstractTestCollection;
+import org.apache.commons.collections.collection.AbstractCollectionTest;
 import org.apache.commons.collections.iterators.AbstractTestListIterator;
 
 /**
@@ -53,7 +53,7 @@ import org.apache.commons.collections.it
  * @author Stephen Colebourne
  * @author Neil O'Toole
  */
-public abstract class AbstractTestList<E> extends AbstractTestCollection<E> {
+public abstract class AbstractTestList<E> extends AbstractCollectionTest<E> {
 
     /**
      * JUnit constructor.

Modified: commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/list/TestTransformedList.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/list/TestTransformedList.java?rev=1369988&r1=1369987&r2=1369988&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/list/TestTransformedList.java (original)
+++ commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/list/TestTransformedList.java Mon Aug  6 20:34:42 2012
@@ -22,7 +22,7 @@ import java.util.List;
 import java.util.ListIterator;
 
 import org.apache.commons.collections.Transformer;
-import org.apache.commons.collections.collection.TestTransformedCollection;
+import org.apache.commons.collections.collection.TransformedCollectionTest;
 
 /**
  * Extension of {@link AbstractTestList} for exercising the {@link TransformedList}
@@ -54,7 +54,7 @@ public class TestTransformedList<E> exte
     @Override
     @SuppressWarnings("unchecked")
     public List<E> makeObject() {
-        return TransformedList.transformingList(new ArrayList<E>(), (Transformer<E, E>) TestTransformedCollection.NOOP_TRANSFORMER);
+        return TransformedList.transformingList(new ArrayList<E>(), (Transformer<E, E>) TransformedCollectionTest.NOOP_TRANSFORMER);
     }
 
     @Override
@@ -62,12 +62,12 @@ public class TestTransformedList<E> exte
     public List<E> makeFullCollection() {
         List<E> list = new ArrayList<E>();
         list.addAll(Arrays.asList(getFullElements()));
-        return TransformedList.transformingList(list, (Transformer<E, E>) TestTransformedCollection.NOOP_TRANSFORMER);
+        return TransformedList.transformingList(list, (Transformer<E, E>) TransformedCollectionTest.NOOP_TRANSFORMER);
     }
 
     @SuppressWarnings("unchecked")
     public void testTransformedList() {
-        List<E> list = TransformedList.transformingList(new ArrayList<E>(), (Transformer<E, E>) TestTransformedCollection.STRING_TO_INTEGER_TRANSFORMER);
+        List<E> list = TransformedList.transformingList(new ArrayList<E>(), (Transformer<E, E>) TransformedCollectionTest.STRING_TO_INTEGER_TRANSFORMER);
         assertEquals(0, list.size());
         E[] els = (E[]) new Object[] {"1", "3", "5", "7", "2", "4", "6"};
         for (int i = 0; i < els.length; i++) {
@@ -119,7 +119,7 @@ public class TestTransformedList<E> exte
         for (int i = 0; i < els.length; i++) {
             originalList.add(els[i]);
         }
-        List<?> list = TransformedList.transformedList(originalList, TestTransformedCollection.STRING_TO_INTEGER_TRANSFORMER);
+        List<?> list = TransformedList.transformedList(originalList, TransformedCollectionTest.STRING_TO_INTEGER_TRANSFORMER);
         assertEquals(els.length, list.size());
         for (int i = 0; i < els.length; i++) {
             assertEquals(true, list.contains(new Integer((String) els[i])));

Modified: commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/map/AbstractTestMap.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/map/AbstractTestMap.java?rev=1369988&r1=1369987&r2=1369988&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/map/TestTransformedMap.java (original)
+++ commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/map/TestTransformedMap.java Mon Aug  6 20:34:42 2012
@@ -23,7 +23,7 @@ import java.util.Set;
 import org.apache.commons.collections.IterableMap;
 import org.apache.commons.collections.Transformer;
 import org.apache.commons.collections.TransformerUtils;
-import org.apache.commons.collections.collection.TestTransformedCollection;
+import org.apache.commons.collections.collection.TransformedCollectionTest;
 
 /**
  * Extension of {@link AbstractTestMap} for exercising the {@link TransformedMap}
@@ -55,7 +55,7 @@ public class TestTransformedMap<K, V> ex
         Map<K, V> map = TransformedMap
                 .transformingMap(
                         new HashMap<K, V>(),
-                        (Transformer<? super K, ? extends K>) TestTransformedCollection.STRING_TO_INTEGER_TRANSFORMER,
+                        (Transformer<? super K, ? extends K>) TransformedCollectionTest.STRING_TO_INTEGER_TRANSFORMER,
                         null);
         assertEquals(0, map.size());
         for (int i = 0; i < els.length; i++) {
@@ -70,7 +70,7 @@ public class TestTransformedMap<K, V> ex
         assertEquals(null, map.remove(els[0]));
         assertEquals(els[0], map.remove(new Integer((String) els[0])));
 
-        map = TransformedMap.transformingMap(new HashMap(), null, TestTransformedCollection.STRING_TO_INTEGER_TRANSFORMER);
+        map = TransformedMap.transformingMap(new HashMap(), null, TransformedCollectionTest.STRING_TO_INTEGER_TRANSFORMER);
         assertEquals(0, map.size());
         for (int i = 0; i < els.length; i++) {
             map.put((K) els[i], (V) els[i]);
@@ -107,7 +107,7 @@ public class TestTransformedMap<K, V> ex
                 .transformingMap(
                         base,
                         null,
-                        (Transformer<? super V, ? extends V>) TestTransformedCollection.STRING_TO_INTEGER_TRANSFORMER);
+                        (Transformer<? super V, ? extends V>) TransformedCollectionTest.STRING_TO_INTEGER_TRANSFORMER);
         assertEquals(3, trans.size());
         assertEquals("1", trans.get("A"));
         assertEquals("2", trans.get("B"));
@@ -127,7 +127,7 @@ public class TestTransformedMap<K, V> ex
                 .transformedMap(
                         base,
                         null,
-                        (Transformer<? super V, ? extends V>) TestTransformedCollection.STRING_TO_INTEGER_TRANSFORMER);
+                        (Transformer<? super V, ? extends V>) TransformedCollectionTest.STRING_TO_INTEGER_TRANSFORMER);
         assertEquals(3, trans.size());
         assertEquals(new Integer(1), trans.get("A"));
         assertEquals(new Integer(2), trans.get("B"));

Modified: commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/map/TestTransformedSortedMap.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/map/TestTransformedSortedMap.java?rev=1369988&r1=1369987&r2=1369988&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/map/TestTransformedSortedMap.java (original)
+++ commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/map/TestTransformedSortedMap.java Mon Aug  6 20:34:42 2012
@@ -26,7 +26,7 @@ import junit.framework.Test;
 import org.apache.commons.collections.BulkTest;
 import org.apache.commons.collections.Transformer;
 import org.apache.commons.collections.TransformerUtils;
-import org.apache.commons.collections.collection.TestTransformedCollection;
+import org.apache.commons.collections.collection.TransformedCollectionTest;
 
 /**
  * Extension of {@link AbstractTestSortedMap} for exercising the {@link TransformedSortedMap}
@@ -70,7 +70,7 @@ public class TestTransformedSortedMap<K,
         SortedMap<K, V> map = TransformedSortedMap
                 .transformingSortedMap(
                         new TreeMap<K, V>(),
-                        (Transformer<? super K, ? extends K>) TestTransformedCollection.STRING_TO_INTEGER_TRANSFORMER,
+                        (Transformer<? super K, ? extends K>) TransformedCollectionTest.STRING_TO_INTEGER_TRANSFORMER,
                         null);
         assertEquals(0, map.size());
         for (int i = 0; i < els.length; i++) {
@@ -95,7 +95,7 @@ public class TestTransformedSortedMap<K,
                 .transformingSortedMap(
                         new TreeMap<K, V>(),
                         null,
-                        (Transformer<? super V, ? extends V>) TestTransformedCollection.STRING_TO_INTEGER_TRANSFORMER);
+                        (Transformer<? super V, ? extends V>) TransformedCollectionTest.STRING_TO_INTEGER_TRANSFORMER);
         assertEquals(0, map.size());
         for (int i = 0; i < els.length; i++) {
             map.put((K) els[i], (V) els[i]);
@@ -132,7 +132,7 @@ public class TestTransformedSortedMap<K,
                 .transformingSortedMap(
                         base,
                         null,
-                        (Transformer<? super V, ? extends V>) TestTransformedCollection.STRING_TO_INTEGER_TRANSFORMER);
+                        (Transformer<? super V, ? extends V>) TransformedCollectionTest.STRING_TO_INTEGER_TRANSFORMER);
         assertEquals(3, trans.size());
         assertEquals("1", trans.get("A"));
         assertEquals("2", trans.get("B"));
@@ -152,7 +152,7 @@ public class TestTransformedSortedMap<K,
                 .transformedSortedMap(
                         base,
                         null,
-                        (Transformer<? super V, ? extends V>) TestTransformedCollection.STRING_TO_INTEGER_TRANSFORMER);
+                        (Transformer<? super V, ? extends V>) TransformedCollectionTest.STRING_TO_INTEGER_TRANSFORMER);
         assertEquals(3, trans.size());
         assertEquals(new Integer(1), trans.get("A"));
         assertEquals(new Integer(2), trans.get("B"));

Modified: commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/set/AbstractTestSet.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/set/AbstractTestSet.java?rev=1369988&r1=1369987&r2=1369988&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/set/TestTransformedSet.java (original)
+++ commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/set/TestTransformedSet.java Mon Aug  6 20:34:42 2012
@@ -21,7 +21,7 @@ import java.util.HashSet;
 import java.util.Set;
 
 import org.apache.commons.collections.Transformer;
-import org.apache.commons.collections.collection.TestTransformedCollection;
+import org.apache.commons.collections.collection.TransformedCollectionTest;
 
 /**
  * Extension of {@link AbstractTestSet} for exercising the {@link TransformedSet}
@@ -54,7 +54,7 @@ public class TestTransformedSet<E> exten
     @SuppressWarnings("unchecked")
     public Set<E> makeObject() {
         return TransformedSet.transformingSet(new HashSet<E>(),
-                (Transformer<E, E>) TestTransformedCollection.NOOP_TRANSFORMER);
+                (Transformer<E, E>) TransformedCollectionTest.NOOP_TRANSFORMER);
     }
 
     @Override
@@ -63,13 +63,13 @@ public class TestTransformedSet<E> exten
         Set<E> list = new HashSet<E>();
         list.addAll(Arrays.asList(getFullElements()));
         return TransformedSet.transformingSet(list,
-                (Transformer<E, E>) TestTransformedCollection.NOOP_TRANSFORMER);
+                (Transformer<E, E>) TransformedCollectionTest.NOOP_TRANSFORMER);
     }
 
     @SuppressWarnings("unchecked")
     public void testTransformedSet() {
         Set<E> set = TransformedSet.transformingSet(new HashSet<E>(),
-                (Transformer<E, E>) TestTransformedCollection.STRING_TO_INTEGER_TRANSFORMER);
+                (Transformer<E, E>) TransformedCollectionTest.STRING_TO_INTEGER_TRANSFORMER);
         assertEquals(0, set.size());
         E[] els = (E[]) new Object[] { "1", "3", "5", "7", "2", "4", "6" };
         for (int i = 0; i < els.length; i++) {
@@ -90,7 +90,7 @@ public class TestTransformedSet<E> exten
         for (int i = 0; i < els.length; i++) {
             originalSet.add(els[i]);
         }
-        Set<?> set = TransformedSet.transformedSet(originalSet, TestTransformedCollection.STRING_TO_INTEGER_TRANSFORMER);
+        Set<?> set = TransformedSet.transformedSet(originalSet, TransformedCollectionTest.STRING_TO_INTEGER_TRANSFORMER);
         assertEquals(els.length, set.size());
         for (int i = 0; i < els.length; i++) {
             assertEquals(true, set.contains(new Integer((String) els[i])));

Modified: commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/set/TestTransformedSortedSet.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/set/TestTransformedSortedSet.java?rev=1369988&r1=1369987&r2=1369988&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/set/TestTransformedSortedSet.java (original)
+++ commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/set/TestTransformedSortedSet.java Mon Aug  6 20:34:42 2012
@@ -25,7 +25,7 @@ import junit.framework.Test;
 
 import org.apache.commons.collections.BulkTest;
 import org.apache.commons.collections.Transformer;
-import org.apache.commons.collections.collection.TestTransformedCollection;
+import org.apache.commons.collections.collection.TransformedCollectionTest;
 
 /**
  * Extension of {@link AbstractTestSortedSet} for exercising the {@link TransformedSortedSet}
@@ -50,7 +50,7 @@ public class TestTransformedSortedSet<E>
     @Override
     @SuppressWarnings("unchecked")
     public SortedSet<E> makeObject() {
-        return TransformedSortedSet.transformingSortedSet(new TreeSet<E>(), (Transformer<E, E>) TestTransformedCollection.NOOP_TRANSFORMER);
+        return TransformedSortedSet.transformingSortedSet(new TreeSet<E>(), (Transformer<E, E>) TransformedCollectionTest.NOOP_TRANSFORMER);
     }
 
     @Override
@@ -58,14 +58,14 @@ public class TestTransformedSortedSet<E>
     public SortedSet<E> makeFullCollection() {
         SortedSet<E> set = new TreeSet<E>();
         set.addAll(Arrays.asList(getFullElements()));
-        return TransformedSortedSet.transformingSortedSet(set, (Transformer<E, E>) TestTransformedCollection.NOOP_TRANSFORMER);
+        return TransformedSortedSet.transformingSortedSet(set, (Transformer<E, E>) TransformedCollectionTest.NOOP_TRANSFORMER);
     }
 
     //-----------------------------------------------------------------------
     @SuppressWarnings("unchecked")
     public void testTransformedSet() {
         SortedSet<E> set = TransformedSortedSet.transformingSortedSet(new TreeSet<E>(),
-                (Transformer<E, E>) TestTransformedCollection.STRING_TO_INTEGER_TRANSFORMER);
+                (Transformer<E, E>) TransformedCollectionTest.STRING_TO_INTEGER_TRANSFORMER);
         assertEquals(0, set.size());
         E[] els = (E[]) new Object[] { "1", "3", "5", "7", "2", "4", "6" };
         for (int i = 0; i < els.length; i++) {
@@ -83,7 +83,7 @@ public class TestTransformedSortedSet<E>
         for (int i = 0; i < els.length; i++) {
             originalSet.add(els[i]);
         }
-        Set<?> set = TransformedSortedSet.transformedSet(originalSet, TestTransformedCollection.STRING_TO_INTEGER_TRANSFORMER);
+        Set<?> set = TransformedSortedSet.transformedSet(originalSet, TransformedCollectionTest.STRING_TO_INTEGER_TRANSFORMER);
         assertEquals(els.length, set.size());
         for (int i = 0; i < els.length; i++) {
             assertEquals(true, set.contains(new Integer((String) els[i])));
--- commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/buffer/TestPredicatedBuffer.java (original)
+++ commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/buffer/TestPredicatedBuffer.java Mon Aug  6 20:34:42 2012
@@ -22,10 +22,10 @@ import org.apache.commons.collections.Ar
 import org.apache.commons.collections.Buffer;
 import org.apache.commons.collections.BufferUnderflowException;
 import org.apache.commons.collections.Predicate;
-import org.apache.commons.collections.collection.TestPredicatedCollection;
+import org.apache.commons.collections.collection.PredicatedCollectionTest;
 
 /**
  * Extension of {@link TestPredicatedCollection} for exercising the
  * {@link PredicatedBuffer} implementation.
  *
  * @since Commons Collections 3.0
@@ -33,7 +33,7 @@ import org.apache.commons.collections.co
  *
  * @author Phil Steitz
  */
-public class TestPredicatedBuffer<E> extends TestPredicatedCollection<E> {
+public class TestPredicatedBuffer<E> extends PredicatedCollectionTest<E> {
 
     public TestPredicatedBuffer(String testName) {
         super(testName);
@@ -22,10 +22,10 @@ import org.apache.commons.collections.Ar
 
 /**
- * Extension of {@link TestPredicatedCollection} for exercising the
+ * Extension of {@link PredicatedCollectionTest} for exercising the
  * {@link PredicatedBuffer} implementation.
  *

Modified: commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/buffer/TestPriorityBuffer.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/buffer/TestPriorityBuffer.java?rev=1369988&r1=1369987&r2=1369988&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/buffer/TestSynchronizedBuffer.java (original)
+++ commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/buffer/TestSynchronizedBuffer.java Mon Aug  6 20:34:42 2012
@@ -21,10 +21,10 @@ import java.util.Collection;
 
 import org.apache.commons.collections.ArrayStack;
 import org.apache.commons.collections.Buffer;
-import org.apache.commons.collections.collection.AbstractTestCollection;
+import org.apache.commons.collections.collection.AbstractCollectionTest;
 
 /**
  * Extension of {@link AbstractTestCollection} for exercising the
  * {@link SynchronizedBuffer} implementation.
  *
  * @since Commons Collections 3.1
@@ -33,7 +33,7 @@ import org.apache.commons.collections.co
  * @author Phil Steitz
  * @author Stephen Colebourne
  */
-public class TestSynchronizedBuffer<E> extends AbstractTestCollection<E> {
+public class TestSynchronizedBuffer<E> extends AbstractCollectionTest<E> {
 
     public TestSynchronizedBuffer(String testName) {
         super(testName);
@@ -21,10 +21,10 @@ import java.util.Collection;
 
 /**
- * Extension of {@link AbstractTestCollection} for exercising the
+ * Extension of {@link AbstractCollectionTest} for exercising the
  * {@link SynchronizedBuffer} implementation.
  *

Modified: commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/buffer/TestTransformedBuffer.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/buffer/TestTransformedBuffer.java?rev=1369988&r1=1369987&r2=1369988&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/TestUnmodifiableCollection.java (original)
+++ commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/collection/UnmodifiableCollectionTest.java Mon Aug  6 20:34:42 2012
@@ -22,7 +22,7 @@ import java.util.Collection;
 import java.util.List;
 
 /**
  * Extension of {@link AbstractTestCollection} for exercising the
  * {@link UnmodifiableCollection} implementation.
  *
  * @since Commons Collections 3.0
@@ -31,9 +31,9 @@ import java.util.List;
  * @author Phil Steitz
  * @author Stephen Colebourne
  */
-public class TestUnmodifiableCollection<E> extends AbstractTestCollection<E> {
+public class UnmodifiableCollectionTest<E> extends AbstractCollectionTest<E> {
 
-    public TestUnmodifiableCollection(String testName) {
+    public UnmodifiableCollectionTest(String testName) {
         super(testName);
     }
 
@@ -22,7 +22,7 @@ import java.util.Collection;
 
 /**
- * Extension of {@link AbstractTestCollection} for exercising the
+ * Extension of {@link AbstractCollectionTest} for exercising the
  * {@link UnmodifiableCollection} implementation.
  *

Modified: commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/list/AbstractTestList.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/list/AbstractTestList.java?rev=1369988&r1=1369987&r2=1369988&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/map/AbstractTestMap.java (original)
+++ commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/map/AbstractTestMap.java Mon Aug  6 20:34:42 2012
@@ -32,14 +32,14 @@ import java.util.Set;
 import org.apache.commons.collections.AbstractTestObject;
 import org.apache.commons.collections.BulkTest;
 import org.apache.commons.collections.CollectionUtils;
-import org.apache.commons.collections.collection.AbstractTestCollection;
+import org.apache.commons.collections.collection.AbstractCollectionTest;
 import org.apache.commons.collections.keyvalue.DefaultMapEntry;
 import org.apache.commons.collections.set.AbstractTestSet;
 
 /**
  * Abstract test class for {@link java.util.Map} methods and contracts.
  * <p>
  * The forces at work here are similar to those in {@link AbstractTestCollection}.
  * If your class implements the full Map interface, including optional
  * operations, simply extend this class, and implement the
  * {@link #makeObject()} method.
@@ -1778,18 +1778,18 @@ public abstract class AbstractTestMap<K,
 
     /**
      * Bulk test {@link Map#values()}.  This method runs through all of
      * the tests in {@link AbstractTestCollection}.
      * After modification operations, {@link #verify()} is invoked to ensure
      * that the map and the other collection views are still valid.
      *
      * @return a {@link AbstractTestCollection} instance for testing the map's
      *    values collection
      */
     public BulkTest bulkTestMapValues() {
         return new TestMapValues();
     }
 
-    public class TestMapValues extends AbstractTestCollection<V> {
+    public class TestMapValues extends AbstractCollectionTest<V> {
         public TestMapValues() {
             super("");
         }
@@ -32,14 +32,14 @@ import java.util.Set;
  * Abstract test class for {@link java.util.Map} methods and contracts.
  * <p>
- * The forces at work here are similar to those in {@link AbstractTestCollection}.
+ * The forces at work here are similar to those in {@link AbstractCollectionTest}.
  * If your class implements the full Map interface, including optional
  * operations, simply extend this class, and implement the
@@ -1778,18 +1778,18 @@ public abstract class AbstractTestMap<K,
     /**
      * Bulk test {@link Map#values()}.  This method runs through all of
-     * the tests in {@link AbstractTestCollection}.
+     * the tests in {@link AbstractCollectionTest}.
      * After modification operations, {@link #verify()} is invoked to ensure
      * that the map and the other collection views are still valid.
@@ -1778,18 +1778,18 @@ public abstract class AbstractTestMap<K,
      * that the map and the other collection views are still valid.
      *
-     * @return a {@link AbstractTestCollection} instance for testing the map's
+     * @return a {@link AbstractCollectionTest} instance for testing the map's
      *    values collection
      */

Modified: commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/map/TestTransformedMap.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/map/TestTransformedMap.java?rev=1369988&r1=1369987&r2=1369988&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/set/AbstractTestSet.java (original)
+++ commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/set/AbstractTestSet.java Mon Aug  6 20:34:42 2012
@@ -22,7 +22,7 @@ import java.util.HashSet;
 import java.util.Iterator;
 import java.util.Set;
 
-import org.apache.commons.collections.collection.AbstractTestCollection;
+import org.apache.commons.collections.collection.AbstractCollectionTest;
 
 /**
  * Abstract test class for {@link Set} methods and contracts.
@@ -36,14 +36,14 @@ import org.apache.commons.collections.co
  * To use, subclass and override the {@link #makeObject()}
  * method.  You may have to override other protected methods if your
  * set is not modifiable, or if your set restricts what kinds of
  * elements may be added; see {@link AbstractTestCollection} for more details.
  *
  * @since Commons Collections 3.0
  * @version $Revision$
  *
  * @author Paul Jack
  */
-public abstract class AbstractTestSet<E> extends AbstractTestCollection<E> {
+public abstract class AbstractTestSet<E> extends AbstractCollectionTest<E> {
 
     /**
      * JUnit constructor.
@@ -128,7 +128,7 @@ public abstract class AbstractTestSet<E>
 
     //-----------------------------------------------------------------------
     /**
      * Return the {@link AbstractTestCollection#collection} fixture, but cast as a Set.  
      */
     @Override
     public Set<E> getCollection() {
@@ -136,7 +136,7 @@ public abstract class AbstractTestSet<E>
     }
 
     /**
      * Return the {@link AbstractTestCollection#confirmed} fixture, but cast as a Set.
      */
     @Override
     public Set<E> getConfirmed() {
@@ -36,14 +36,14 @@ import org.apache.commons.collections.co
  * method.  You may have to override other protected methods if your
  * set is not modifiable, or if your set restricts what kinds of
- * elements may be added; see {@link AbstractTestCollection} for more details.
+ * elements may be added; see {@link AbstractCollectionTest} for more details.
  *
  * @since Commons Collections 3.0
@@ -128,7 +128,7 @@ public abstract class AbstractTestSet<E>
     //-----------------------------------------------------------------------
     /**
-     * Return the {@link AbstractTestCollection#collection} fixture, but cast as a Set.  
+     * Return the {@link AbstractCollectionTest#collection} fixture, but cast as a Set.  
      */
     @Override
@@ -136,7 +136,7 @@ public abstract class AbstractTestSet<E>
 
     /**
-     * Return the {@link AbstractTestCollection#confirmed} fixture, but cast as a Set.
+     * Return the {@link AbstractCollectionTest#confirmed} fixture, but cast as a Set.
      */
     @Override

Modified: commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/set/TestTransformedSet.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/set/TestTransformedSet.java?rev=1369988&r1=1369987&r2=1369988&view=diff
==============================================================================